@@ -5,38 +5,42 @@
 #' 
 #' @noRd 
 #'
-.barplot <- function(dt, timeStep, variable, confInt = 0, maxValue,
+.barplot <- function(dt, timeStep, variable, typeConfInt = FALSE, confInt = 0, maxValue,
                      colors = NULL,
                      main = NULL,
                      ylab = NULL,
                      legend = TRUE,
                      legendItemsPerRow = 5,
-                     width = NULL, height = NULL, ...) {
+                     width = NULL, height = NULL, language = "en", ...) {
   
   if (is.null(dt$mcYear)) {
     dt <- dt[, .(value = mean(value)), by = element] 
   } else {
     dt <- dt[, .(value = mean(value)), by = .(element, mcYear)] 
     
-    if (confInt == 0) {
-      dt <- dt[, .(value = mean(value)), by = .(element)]
-    } else {
-      uniqueElements <- sort(unique(dt$element))
-      
-      alpha <- (1 - confInt) / 2
-      .getConfInt <- function(x) {
-        q <- quantile(x, c(alpha, 1 - alpha))
-        m <- mean(x)
-        list(value = m, l = m - q[1], u = q[2] - m)
+    if(typeConfInt){
+      if (confInt == 0) {
+        dt <- dt[, .(value = mean(value)), by = .(element)]
+      } else {
+        uniqueElements <- as.character(sort(unique(dt$element)))
+        
+        alpha <- (1 - confInt) / 2
+        .getConfInt <- function(x) {
+          q <- quantile(x, c(alpha, 1 - alpha))
+          m <- mean(x)
+          list(value = m, l = m - q[1], u = q[2] - m)
+        }
+        dt <- dt[, .getConfInt(value), by = .(element)]
       }
-      dt <- dt[, .getConfInt(value), by = .(element)]
     }
   }
   # print(dt)
   dt[,"element" := as.character(element)]
   variable <- paste0(variable, collapse = " ; ")
   if (is.null(ylab)) ylab <- variable
-  if (is.null(main) | isTRUE(all.equal("", main))) main <- paste("Comparison of", variable)
+  if (is.null(main) | isTRUE(all.equal("", main))){
+    main <- paste(.getLabelLanguage("Comparison of", language), variable)
+  }
   
   g <- plot_ly(dt,  textfont = list(color = '#000000')) %>% 
     config(displayModeBar = FALSE) %>% 
