@@ -1,6 +1,6 @@
 context("prodStack no interactive")
 
-describe("prodStack, no interactive", {
+test_that("prodStack, no interactive", {
   if(.requireRhdf5_Antares(stopP = FALSE)){
     dta <- readAntares(areas = "all", showProgress = FALSE)
     g <- plotXY(dta, "NODU", "LOAD", precision = 50, sizeOnCount = FALSE)
